# API reference

::: anyioutils
    options:
      inherited_members: true
      unwrap_annotated: true
      members:
      - CancelledError
      - Event
      - Future
      - InvalidStateError
      - Monitor
      - Queue
      - Task
      - TaskGroup
      - create_task
      - start_guest_run
      - start_task
      - wait
